@@ -35,7 +35,6 @@
 #endif
 
 #include "InputArea.h"
-#include "MouseHandler.h"
 #include "PaintLayer.h"
 
 namespace nux
@@ -58,7 +57,7 @@ namespace nux
       @param int          The height of the window.
       @param Geometry&    The tentative size of the window.
   */
-  typedef void (*ConfigureNotifyCallback) (int, int, Geometry &, void *);
+  typedef void(*ConfigureNotifyCallback) (int, int, Geometry &, void *);
 
   /*!
     A floating area on top of the main window.
@@ -66,23 +65,18 @@ namespace nux
   */
   class BaseWindow: public View
   {
-    NUX_DECLARE_OBJECT_TYPE (BaseWindow, View);
+    NUX_DECLARE_OBJECT_TYPE(BaseWindow, View);
   public:
-    BaseWindow (const TCHAR *WindowName = TEXT (""), NUX_FILE_LINE_PROTO);
+    BaseWindow(const char *WindowName = "", NUX_FILE_LINE_PROTO);
     virtual ~BaseWindow();
 
     nux::Property<bool> premultiply;
 
     virtual Area* FindAreaUnderMouse(const Point& mouse_position, NuxEventType event_type);
-    virtual long ProcessEvent (IEvent &ievent, long TraverseInfo, long ProcessEventInfo);
-    virtual void Draw (GraphicsEngine &GfxContext, bool force_draw);
-    virtual void DrawContent (GraphicsEngine &GfxContext, bool force_draw);
-    virtual void PostDraw (GraphicsEngine &GfxContext, bool force_draw);
+    virtual void Draw(GraphicsEngine &graphics_engine, bool force_draw);
+    virtual void DrawContent(GraphicsEngine &graphics_engine, bool force_draw);
+    virtual void PostDraw(GraphicsEngine &graphics_engine, bool force_draw);
 
-    void AddWidget (View *ic);
-    void AddWidget (View *ic, int stretchfactor);
-    void AddWidget (std::list<View *> *ViewList);
-    
     virtual Layout* GetLayout();
     virtual bool SetLayout(Layout *layout);
 
@@ -90,37 +84,37 @@ namespace nux
     /*!
         Push this view one level up the ViewWindow stack. Does it even if the view is hidden.
     */
-    void PushHigher (BaseWindow* floating_view);
+    void PushHigher(BaseWindow* floating_view);
 
     //! Push the view one level down the ViewWindow stack.
     /*!
         Push this view one level down the ViewWindow stack. Does it even if the view is hidden.
     */
-    void PushLower (BaseWindow* floating_view);
+    void PushLower(BaseWindow* floating_view);
 
     //! Push the view to the front of the ViewWindow stack.
     /*!
         Push this view to the top of the ViewWindow stack. Does it even if the view is hidden.
         If a valid ViewWindow has been forced at the top of the stack with a call to WindowCompositor::SetAlwaysOnFrontWindow(),
         then this view will be positioned one level below that view.
-        \sa SetAlwaysOnFrontWindow ();
+        \sa SetAlwaysOnFrontWindow();
     */
-    void PushToFront ();
-      
+    void PushToFront();
+
     //! Push the view to the back of the ViewWindow stack.
     /*!
         Push this view to the back of the ViewWindow stack. Does it even if the view is hidden.
     */
-    void PushToBack ();
+    void PushToBack();
 
     //! Set the window size to respect the layout container.
     /*!
         Set the window size to be such that the container layout size remains the same after ComputeSizeLayout2 is
-        called on the layout. The window elements (title bar, minimize and close buttons) are positioned accordingly.
+        called on the layout. The window elements(title bar, minimize and close buttons) are positioned accordingly.
         The size grip is not responding anymore.
         @param b If b is true, the window size respect the size the layout container.
     */
-    virtual void SetWindowSizeMatchLayout (bool b)
+    virtual void SetWindowSizeMatchLayout(bool b)
     {
       _size_match_layout = b;
     }
@@ -134,12 +128,12 @@ namespace nux
       return _size_match_layout;
     }
 
-    virtual void ShowWindow (bool b, bool StartModal = false);
-    void StopModal ();
-    bool IsModal () const;
-    bool IsVisible () const;
+    virtual void ShowWindow(bool b, bool StartModal = false);
+    void StopModal();
+    bool IsModal() const;
+    bool IsVisible() const;
 
-    virtual void SetGeometry (const Geometry &geo);
+    virtual void SetGeometry(const Geometry &geo);
 
     /*!
         Call this function to set a callback function that is called when this object is need to be resized or re-positioned.
@@ -147,24 +141,29 @@ namespace nux
         @param Data     The callback data.
     */
 
-    void SetConfigureNotifyCallback (ConfigureNotifyCallback Callback, void *Data);
+    void SetConfigureNotifyCallback(ConfigureNotifyCallback Callback, void *Data);
 
-    void SetBackgroundLayer (AbstractPaintLayer *layer);
-    void SetBackgroundColor (const Color &color);
+    void SetBackgroundLayer(AbstractPaintLayer *layer);
+    void SetBackgroundColor(const Color &color);
 
-    void  SetOpacity (float opacity);
-    float GetOpacity ();
+    void  SetOpacity(float opacity);
+    float GetOpacity();
 
     #if defined(NUX_OS_LINUX)
-    void EnableInputWindow (bool        b,
+    void EnableInputWindow(bool        b,
                             const char* title = "nux input window",
                             bool        take_focus = False,
                             bool        override_redirect = False);
-    bool InputWindowEnabled ();
-    void InputWindowEnableStruts (bool enable);
-    bool InputWindowStrutsEnabled ();
-    void SetInputFocus ();
-    Window GetInputWindowId ();
+    bool InputWindowEnabled();
+
+    void InputWindowEnableStruts(bool enable);
+    bool InputWindowStrutsEnabled();
+
+    void InputWindowEnableOverlayStruts(bool enable);
+    bool InputWindowOverlayStrutsEnabled();
+
+    void SetInputFocus();
+    Window GetInputWindowId();
     #endif
 
     //! Set an InputArea to receive the keyboard focus when the BaseWIndow receives the NUX_WINDOW_ENTER_FOCUS event.
@@ -172,23 +171,23 @@ namespace nux
         \sa _enter_focus_input_area.
         @param input_area An InputArea pointer object. Must be a child of this BaseWindow.
     */
-    void SetEnterFocusInputArea (InputArea *input_area);
+    void SetEnterFocusInputArea(InputArea *input_area);
 
 
     //! Get the backup texture data of this BaseWindow,
-    void* GetBackupTextureData (int &width, int &height, int &format);
+    void* GetBackupTextureData(int &width, int &height, int &format);
 
     //! Emit a signal when the BaseWindow becomes visible.
     sigc::signal<void, BaseWindow*> sigVisible;
     //! Emit a signal when the BaseWindow becomes hidden.
     sigc::signal<void, BaseWindow*> sigHidden;
 
-    NString GetWindowName ()
+    NString GetWindowName()
     {
       return _name;
     }
   protected:
-    
+
     void SetAcceptKeyNavFocus(bool accept);
     bool accept_key_nav_focus_;
     virtual bool AcceptKeyNavFocus();
@@ -204,9 +203,9 @@ namespace nux
 
     friend class ComboBox_Logic_WindowView;
 
-    virtual void PreLayoutManagement ();
-    virtual long PostLayoutManagement (long LayoutResult);
-    virtual void PositionChildLayout (float offsetX, float offsetY);
+    virtual void PreLayoutManagement();
+    virtual long PostLayoutManagement(long LayoutResult);
+    virtual void ComputeContentPosition(float offsetX, float offsetY);
     //! Layout the window elements.
     /*!
         Layout elements such as button on the title bar, and the resize widget according to the current
@@ -220,30 +219,30 @@ namespace nux
         @param Width    New width of the window.
         @param Height   New height of the window.
     */
-    virtual void NotifyConfigurationChange (int Width, int Height);
+    virtual void NotifyConfigurationChange(int Width, int Height);
 
     int GetBorder() const;
     int GetTopBorder() const;
-    void SetBorder (int border);
-    void SetTopBorder (int border);
+    void SetBorder(int border);
+    void SetTopBorder(int border);
     int m_TopBorder;
     int m_Border;
     boost::scoped_ptr<AbstractPaintLayer> _paint_layer;
 
     bool _entering_visible_state;  //!< the window is about to be made visible during event processing
     bool _entering_hidden_state;   //!< the window is about to be made hidden during event processing
-    
-    bool ChildNeedsRedraw ();
+
+    bool ChildNeedsRedraw();
 
     #if defined(NUX_OS_LINUX)
     bool m_input_window_enabled;
     XInputWindow *m_input_window;
     #endif
-    
+
   private:
     //! Contains the background of the texture. Can be used to blur. It is set by the window compositor.
     ObjectPtr<BaseTexture> _background_texture;
-   
+
     NString _name;
     bool _size_match_layout;
     bool _is_visible;
