@@ -24,7 +24,6 @@
 #define INPUTAREA_H
 
 #include "Area.h"
-#include "MouseHandler.h"
 
 #if defined(NUX_OS_WINDOWS)
   #include "NuxGraphics/Events.h"
@@ -43,24 +42,11 @@ namespace nux
   class InputArea : public Area
   {
   public:
-    NUX_DECLARE_OBJECT_TYPE (InputArea, Area);
+    NUX_DECLARE_OBJECT_TYPE(InputArea, Area);
   public:
-    InputArea (NUX_FILE_LINE_PROTO);
+    InputArea(NUX_FILE_LINE_PROTO);
     virtual ~InputArea();
 
-    //! Simulate a mouse down state on an area
-    /*!
-        Simulate a mouse down event on an area at the provided relative coordinates. If the provided coordinates
-        do not fall inside the geometry of the area, return false.
-        @param x Coordinates of the mouse down event relative to the top left corner of the area.
-        @param y Coordinates of the mouse down event relative to the top left corner of the area.
-        @return True if the simulated action was successful.
-    */
-    bool ForceStartFocus (int x, int y);
-    void ForceStopFocus (int x, int y);
-
-    virtual long OnEvent (Event &ievent, long TraverseInfo, long ProcessEventInfo);
-
     //! Draw InputArea.
     /*!
         Draw a colored quad using m_AreaColor.
@@ -68,18 +54,14 @@ namespace nux
         If force_draw is true then the system requests that all objects redraw themselves completely.
         \param force_draw.
     */
-    virtual void OnDraw (GraphicsEngine &GfxContext, bool force_draw);
+    virtual void OnDraw(GraphicsEngine &graphics_engine, bool force_draw);
 
-    virtual void OverlayDrawing (GraphicsEngine &GfxContext) {}
+    virtual void OverlayDrawing(GraphicsEngine &graphics_engine) {}
 
     bool HasKeyboardFocus();
-    void SetKeyboardFocus (bool b);
-    int GetMouseX();
-    int GetMouseY();
-    
-    bool HasMouseFocus();
+
     bool MouseFocusOnOtherArea();
-    void CaptureMouseDownAnyWhereElse (bool b);
+    void CaptureMouseDownAnyWhereElse(bool b);
     bool IsCaptureMouseDownAnyWhereElse() const;
 
     Area* FindAreaUnderMouse(const Point& mouse_position, NuxEventType event_type);
@@ -87,27 +69,23 @@ namespace nux
                           unsigned long x11_key_code,
                           unsigned long special_keys_state);
 
+    virtual bool AcceptKeyNavFocus() const;
+    
+  protected:
+
   private:
     bool _dnd_enabled_as_source;
     bool _dnd_enabled_as_target;
-    //bool m_EnableKeyboardInput;
   public:
-//    void EnableKeyEntry(bool b)
-//    {
-//        m_EnableKeyboardInput = true;
-//    }
-//
-//    bool IsEnableKeyEntry()
-//    {
-//        return m_EnableKeyboardInput; //m_KeyboardHandler.IsEnableKeyEntry();
-//    }
-
     // Override the virtual methods from Object Base
     // Here, we get a change to update the text of the keyboard handler.
-    virtual void SetBaseString (const TCHAR *Caption);
+    virtual void SetBaseString(const char *Caption);
 
     void SetKeyboardReceiverIgnoreMouseDownOutside(bool ignore_mouse_down_outside);
 
+    void SetAcceptKeyNavFocusOnMouseDown(bool accept);
+    void SetAcceptKeyNavFocusOnMouseEnter(bool accept);
+
     bool KeyboardReceiverIgnoreMouseDownOutside();
 
     virtual bool IsArea() const
@@ -115,16 +93,12 @@ namespace nux
       return true;
     }
 
-    // This method reset the mouse position inside the Area. This is necessary for areas that serve as Drag
-    // when the area position is referred to (x_root, y_root) instead of being the system window coordinates (0, 0).
-    void SetAreaMousePosition (int x, int y);
-
-    void GrabPointer ();
-    void GrabKeyboard ();
-    void UnGrabPointer ();
-    void UnGrabKeyboard ();
-    bool OwnsPointerGrab ();
-    bool OwnsKeyboardGrab ();
+    void GrabPointer();
+    void GrabKeyboard();
+    void UnGrabPointer();
+    void UnGrabKeyboard();
+    bool OwnsPointerGrab();
+    bool OwnsKeyboardGrab();
 
     //! Return true if this Area is the owner of the mouse pointer.
     /*!
@@ -135,11 +109,12 @@ namespace nux
     */
     bool IsMouseOwner();
 
-    //! Returns true if the mouse pointer is inside the Area.
+    //! Returns true if the mouse pointer has been determined as inside the this area, following event processing.
     /*!
-        Returns true if during a call to FindAreaUnderMouse it the Area has been determined to be directly under the
-        mouse pointer. Note that is is true only for the first area that is found. there might be other areas that 
-        which have the mouse pointer inside of them.
+        Returns true if during a call to FindAreaUnderMouse, this area has been determined to be directly under the
+        mouse pointer. Note that this is true only for the first area that is found. There might be other areas that 
+        which have the mouse pointer inside of them. \n
+        Call Area::IsMousePointerInside to find out if the mouse pointer is inside an area.
         
         @return Return true if the mouse pointer is inside the Area.
     */
@@ -151,11 +126,11 @@ namespace nux
     //! Returns true if the double click signal is enable for this InputArea.
     bool DoubleClickEnabled() const;
 
-    AreaEventProcessor _event_processor;
+    bool mouse_in_;
 
-#if defined (NUX_OS_LINUX)
-    void HandleDndEnter() {ProcessDndEnter ();}
-    void HandleDndLeave() {ProcessDndLeave ();}
+#if defined(NUX_OS_LINUX)
+    void HandleDndEnter() {ProcessDndEnter();}
+    void HandleDndLeave() {ProcessDndLeave();}
 #endif
   private:
 
@@ -163,7 +138,7 @@ namespace nux
     /*!
         Bypass OnEvent and performs a simplified event processing mechanism.
     */
-    long ProcessEventInExclusiveMode (Event &ievent, long TraverseInfo, long ProcessEventInfo);
+    long ProcessEventInExclusiveMode(Event &event, long TraverseInfo, long ProcessEventInfo);
 
     void HandleDndMove  (Event &event);
     void HandleDndDrop  (Event &event);
@@ -172,48 +147,50 @@ namespace nux
     /*
         Color of the InputArea use to draw a colored quad when OnDraw() is called.
     */
-    Color m_AreaColor;
+    Color area_color_;
     
     int _dnd_safety_x;
     int _dnd_safety_y;
 
   protected:
-
-    bool _has_keyboard_focus;
     bool _capture_mouse_down_any_where_else;
     bool _double_click;     //!< If True, this InputArea can emit the signal mouse_double_click. Default is false.
 
     bool _keyboard_receiver_ignore_mouse_down_outside;
 
-#if defined (NUX_OS_LINUX)
+    bool accept_key_nav_focus_on_mouse_down_;
+    bool accept_key_nav_focus_on_mouse_enter_;
+
+
+#if defined(NUX_OS_LINUX)
     // DnD support
     // Rather than being implemented with signals, DND support is implemented with protected virtual function.
     // This ensure that a class and it subclass don't process the same event more than once!
 
     virtual void ProcessDndMove  (int x, int y, std::list<char *>mimes);
     virtual void ProcessDndDrop  (int x, int y);
-    virtual void ProcessDndEnter ();
-    virtual void ProcessDndLeave ();
+    virtual void ProcessDndEnter();
+    virtual void ProcessDndLeave();
 
-    void SendDndStatus (bool accept, DndAction action, Geometry region);
-    void SendDndFinished (bool accepted, DndAction action);
+    void SendDndStatus(bool accept, DndAction action, Geometry region);
+    void SendDndFinished(bool accepted, DndAction action);
     
-    void SetDndEnabled (bool as_source, bool as_target);
+    void SetDndEnabled(bool as_source, bool as_target);
     
     virtual bool                    DndSourceDragBegin      ();
     virtual NBitmapData *           DndSourceGetDragImage   ();
     virtual std::list<const char *> DndSourceGetDragTypes   ();
-    virtual const char *            DndSourceGetDataForType (const char *type, int *size, int *format);
+    virtual const char *            DndSourceGetDataForType(const char *type, int *size, int *format);
     virtual void                    DndSourceDragFinished   (DndAction result);
     
-    void StartDragAsSource ();
+    void StartDragAsSource();
     
-    static NBitmapData *           InnerDndSourceGetDragImage (void *data) { return static_cast<InputArea *> (data)->DndSourceGetDragImage ();       }
-    static std::list<const char *> InnerDndSourceGetDragTypes (void *data) { return static_cast<InputArea *> (data)->DndSourceGetDragTypes ();       }
-    static void                    InnerDndSourceDragFinished (DndAction result, void *data);
+    static NBitmapData *           InnerDndSourceGetDragImage(void *data) { return static_cast<InputArea *> (data)->DndSourceGetDragImage();       }
+    static std::list<const char *> InnerDndSourceGetDragTypes(void *data) { return static_cast<InputArea *> (data)->DndSourceGetDragTypes();       }
+    static void                    InnerDndSourceDragFinished(DndAction result, void *data);
     
-    static const char * InnerDndSourceGetDataForType (const char *type, int *size, int *format, void *data) 
-      { return static_cast<InputArea *> (data)->DndSourceGetDataForType (type, size, format); }
+    static const char * InnerDndSourceGetDataForType(const char *type, int *size, int *format, void *data) 
+      { return static_cast<InputArea *> (data)->DndSourceGetDataForType(type, size, format); }
 #endif
 
   public:
@@ -223,74 +200,74 @@ namespace nux
     //! Signal emitted when the InputArea receives a mouse down event.
     /*!
         @param void Return type of the callback hooked to this signal.
-        @param int Mouse X position (1st parameter of the callback).
-        @param int Mouse Y position (2nd parameter of the callback).
-        @param unsigned long Mouse button states (3rd parameter of the callback).
-        @param unsigned long Keyboard special keys states (4th parameter of the callback).
+        @param int Mouse X position(1st parameter of the callback).
+        @param int Mouse Y position(2nd parameter of the callback).
+        @param unsigned long Mouse button states(3rd parameter of the callback).
+        @param unsigned long Keyboard special keys states(4th parameter of the callback).
     */
     sigc::signal<void, int, int, unsigned long, unsigned long> mouse_down;
     
     //! Signal emitted when the InputArea receives a mouse up event.
     /*!
         @param void Return type of the callback hooked to this signal.
-        @param int Mouse X position (1st parameter of the callback).
-        @param int Mouse Y position (2nd parameter of the callback).
-        @param unsigned long Mouse button states (3rd parameter of the callback).
-        @param unsigned long Keyboard special keys states (4th parameter of the callback).
+        @param int Mouse X position(1st parameter of the callback).
+        @param int Mouse Y position(2nd parameter of the callback).
+        @param unsigned long Mouse button states(3rd parameter of the callback).
+        @param unsigned long Keyboard special keys states(4th parameter of the callback).
     */
     sigc::signal<void, int, int, unsigned long, unsigned long> mouse_up;
     
     //! Signal emitted when the InputArea receives a mouse enter event.
     /*!
         @param void Return type of the callback hooked to this signal.
-        @param int Mouse X position (1st parameter of the callback).
-        @param int Mouse Y position (2nd parameter of the callback).
-        @param unsigned long Mouse button states (3rd parameter of the callback).
-        @param unsigned long Keyboard special keys states (4th parameter of the callback).
+        @param int Mouse X position(1st parameter of the callback).
+        @param int Mouse Y position(2nd parameter of the callback).
+        @param unsigned long Mouse button states(3rd parameter of the callback).
+        @param unsigned long Keyboard special keys states(4th parameter of the callback).
     */
     sigc::signal<void, int, int, unsigned long, unsigned long> mouse_enter;
     
     //! Signal emitted when the InputArea receives a mouse leave event.
     /*!
         @param void Return type of the callback hooked to this signal.
-        @param int Mouse X position (1st parameter of the callback).
-        @param int Mouse Y position (2nd parameter of the callback).
-        @param unsigned long Mouse button states (3rd parameter of the callback).
-        @param unsigned long Keyboard special keys states (4th parameter of the callback).
+        @param int Mouse X position(1st parameter of the callback).
+        @param int Mouse Y position(2nd parameter of the callback).
+        @param unsigned long Mouse button states(3rd parameter of the callback).
+        @param unsigned long Keyboard special keys states(4th parameter of the callback).
     */
     sigc::signal<void, int, int, unsigned long, unsigned long> mouse_leave;
     
     //! Signal emitted when the InputArea receives a mouse down followed later by a mouse release over its surface.
     /*!
         @param void Return type of the callback hooked to this signal.
-        @param int Mouse X position (1st parameter of the callback).
-        @param int Mouse Y position (2nd parameter of the callback).
-        @param unsigned long Mouse button states (3rd parameter of the callback).
-        @param unsigned long Keyboard special keys states (4th parameter of the callback).
+        @param int Mouse X position(1st parameter of the callback).
+        @param int Mouse Y position(2nd parameter of the callback).
+        @param unsigned long Mouse button states(3rd parameter of the callback).
+        @param unsigned long Keyboard special keys states(4th parameter of the callback).
     */
     sigc::signal<void, int, int, unsigned long, unsigned long> mouse_click;
     
     //! Signal emitted when the InputArea receives a double click event.
     /*!
         @param void Return type of the callback hooked to this signal.
-        @param int Mouse X position (1st parameter of the callback).
-        @param int Mouse Y position (2nd parameter of the callback).
-        @param unsigned long Mouse button states (3rd parameter of the callback).
-        @param unsigned long Keyboard special keys states (4th parameter of the callback).
+        @param int Mouse X position(1st parameter of the callback).
+        @param int Mouse Y position(2nd parameter of the callback).
+        @param unsigned long Mouse button states(3rd parameter of the callback).
+        @param unsigned long Keyboard special keys states(4th parameter of the callback).
     */
     sigc::signal<void, int, int, unsigned long, unsigned long> mouse_double_click;
     
-    //! Signal emitted when the InputArea receives a mouse down event, followed later by a mouse move event (while the mouse is still pressed).
+    //! Signal emitted when the InputArea receives a mouse down event, followed later by a mouse move event(while the mouse is still pressed).
     /*!
         @param void Return type of the callback hooked to this signal.
-        @param int Mouse X position (1st parameter of the callback).
-        @param int Mouse Y position (2nd parameter of the callback).
-        @param int Mouse X delta (3thr parameter of the callback).
-        @param int Mouse Y delta (4th parameter of the callback).
-        @param unsigned long Mouse button states (5th parameter of the callback).
-        @param unsigned long Keyboard special keys states (6th parameter of the callback).
+        @param int Mouse X position(1st parameter of the callback).
+        @param int Mouse Y position(2nd parameter of the callback).
+        @param int Mouse X delta(3thr parameter of the callback).
+        @param int Mouse Y delta(4th parameter of the callback).
+        @param unsigned long Mouse button states(5th parameter of the callback).
+        @param unsigned long Keyboard special keys states(6th parameter of the callback).
     */
-    sigc::signal<void, int, int, int, int, unsigned long, unsigned long> mouse_drag; // send (current X, current Y, delta X, delta Y)
+    sigc::signal<void, int, int, int, int, unsigned long, unsigned long> mouse_drag; // send(current X, current Y, delta X, delta Y)
 
     //! Signal emitted when the InputArea receives a mouse wheel event.
     sigc::signal < void,
@@ -299,7 +276,7 @@ namespace nux
          int,            // mouse wheel delta: +120/-120 correspond to one notch of the wheel
          unsigned long,  // mouse state
          unsigned long   // key state
-         > mouse_wheel; // send (current X, current Y, delta X, delta Y)
+         > mouse_wheel; // send(current X, current Y, delta X, delta Y)
 
     //! Signal emitted when the InputArea receives a key release event.
     sigc::signal<void, unsigned int, unsigned long, unsigned long> key_up;
@@ -313,7 +290,7 @@ namespace nux
          unsigned long       ,   /*event type*/
          unsigned long       ,   /*event keysym*/
          unsigned long       ,   /*event state*/
-         const TCHAR*        ,   /*character*/
+         const char*        ,   /*character*/
          unsigned short          /*key repeat count*/
          > key_down;
 
@@ -333,11 +310,11 @@ namespace nux
     sigc::signal<void, InputArea*> start_keyboard_grab;
     sigc::signal<void, InputArea*> end_keyboard_grab;
 
-    void DoSetFocused (bool focus);
-
     protected:
 
       virtual bool AcceptKeyNavFocus();
+      virtual bool AcceptKeyNavFocusOnMouseDown() const;
+      virtual bool AcceptKeyNavFocusOnMouseEnter() const;
 
       // == Signals with 1 to 1 mapping to input device ==
       virtual void EmitMouseDownSignal        (int x, int y, unsigned long mouse_button_state, unsigned long special_keys_state);
@@ -360,10 +337,7 @@ namespace nux
       virtual void EmitMouseLeaveSignal       (int x, int y, unsigned long mouse_button_state, unsigned long special_keys_state);
 
       virtual void EmitMouseClickSignal       (int x, int y, unsigned long mouse_button_state, unsigned long special_keys_state);
-      virtual void EmitMouseDoubleClickSignal (int x, int y, unsigned long mouse_button_state, unsigned long special_keys_state);
-
-      virtual void EmitStartKeyboardFocus();
-      virtual void EmitEndKeyboardFocus();
+      virtual void EmitMouseDoubleClickSignal(int x, int y, unsigned long mouse_button_state, unsigned long special_keys_state);
 
       virtual void EmitMouseDownOutsideArea   (int x, int y, unsigned long mouse_button_state, unsigned long special_keys_state);
 
